summaryrefslogtreecommitdiff
path: root/apps/gperf/src/Bool_Array.h
diff options
context:
space:
mode:
Diffstat (limited to 'apps/gperf/src/Bool_Array.h')
-rw-r--r--apps/gperf/src/Bool_Array.h81
1 files changed, 45 insertions, 36 deletions
diff --git a/apps/gperf/src/Bool_Array.h b/apps/gperf/src/Bool_Array.h
index da76fd7d3e6..0089295f748 100644
--- a/apps/gperf/src/Bool_Array.h
+++ b/apps/gperf/src/Bool_Array.h
@@ -1,25 +1,27 @@
// -*- C++ -*-
-// $Id$
-
-// Copyright (C) 1989 Free Software Foundation, Inc.
-// written by Douglas C. Schmidt (schmidt@cs.wustl.edu)
-
-// This file is part of GNU GPERF.
-
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU General Public License for more details.
-
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+/**
+ * $Id$
+ *
+ * Copyright (C) 1989 Free Software Foundation, Inc.
+ * written by Douglas C. Schmidt (schmidt@cs.wustl.edu)
+ *
+ * This file is part of GNU GPERF.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
#ifndef BOOL_ARRAY_H
#define BOOL_ARRAY_H
@@ -34,41 +36,48 @@
#if defined (ACE_HAS_GPERF)
+#if defined (__BORLANDC__) && (__BORLANDC__ < 0x630)
+#include "gperf_export.h"
+#endif
+
+/**
+ * Efficient lookup table abstraction implemented as a "Generation
+ * Number" Array.
+ *
+ * Uses a "Generation Numbering" implementation to minimize
+ * initialization time.
+ */
+#if defined (__BORLANDC__) && (__BORLANDC__ < 0x630)
+class ACE_GPERF_Export Bool_Array
+#else
class Bool_Array
+#endif
{
- // = TITLE
- // Efficient lookup table abstraction implemented as a "Generation
- // Number" Array.
- //
- // = DESCRIPTION
- // Uses a "Generation Numbering" implementation to minimize
- // initialization time.
public:
- // = Initialization and termination methods.
+ /// Constructor
Bool_Array (void);
- // Constructor
+ /// Initialize the array (requires O(n) time).
int open (u_long);
- // Initialize the array (requires O(n) time).
+ /// Destructor.
~Bool_Array (void);
- // Destructor.
+ /// Locate the @a value in the array (requires O(1) time).
int find (u_long value);
- // Locate the <value> in the array (requires O(1) time).
+ /// Reinitializes the array (requires O(1) time).
void reset (void);
- // Reinitializes the array (requires O(1) time).
private:
+ /// Initialization of the index space.
unsigned long *storage_array_;
- // Initialization of the index space.
+ /// Keep track of the current Generation.
unsigned long generation_number_;
// Keep track of the current Generation.
unsigned long size_;
- // Keep track of array size.
};
#endif /* ACE_HAS_GPERF */
@@ -34,41 +36,48 @@
unsigned long generation_number_;
- // Keep track of the current Generation.
+ /// Keep track of array size.
unsigned long size_;